from __future__ import absolute_import, division, print_function, unicode_literals


ASSET_MANAGER_TYPES = {'Accredited Investor', 'Bank', 'Broker', 'Corporate Treasury', 'Family Office',
                       'Fund Administrator', 'Fund Manager', 'Hedge Fund', 'Individual', 'Private Equity',
                       'Venture Capital', 'Data Provider'}
RELATIONSHIP_TYPES = {'Administrator', 'External', 'Front Office', 'Employee', 'Data Provider'}
ACCOUNT_TYPES = {'Internal', 'Test', 'Basic', 'Professional'}